==> distribution-5.55.0.zip: drr/enrichment/upi/validation/exists/UpiDataOnlyExistsValidator.java <==
package drr.enrichment.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.enrichment.upi.UpiData;
import drr.standards.iso.upi.AnnaDsbUpiRecord;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class UpiDataOnlyExistsValidator implements ValidatorWithArg<UpiData, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends UpiData> ValidationResult<UpiData> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("upiRecord", ExistenceChecker.isSet((AnnaDsbUpiRecord) o.getUpiRecord()))
				.put("upiOfUnderlying", ExistenceChecker.isSet((Boolean) o.getUpiOfUnderlying()))
				.put("upiValidation", ExistenceChecker.isSet((Boolean) o.getUpiValidation()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("UpiData", ValidationResult.ValidationType.ONLY_EXISTS, "UpiData", path, "");
		}
		return failure("UpiData", ValidationResult.ValidationType.ONLY_EXISTS, "UpiData", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.0.0-dev.128.zip: drr/enrichment/upi/validation/exists/UpiDataOnlyExistsValidator.java <==
package drr.enrichment.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.enrichment.upi.UpiData;
import drr.standards.iosco.upi.AnnaDsbUpiRecord;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class UpiDataOnlyExistsValidator implements ValidatorWithArg<UpiData, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends UpiData> ValidationResult<UpiData> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("upiRecord", ExistenceChecker.isSet((AnnaDsbUpiRecord) o.getUpiRecord()))
				.put("upiOfUnderlying", ExistenceChecker.isSet((Boolean) o.getUpiOfUnderlying()))
				.put("upiValidation", ExistenceChecker.isSet((Boolean) o.getUpiValidation()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("UpiData", ValidationType.ONLY_EXISTS, "UpiData", path, "");
		}
		return failure("UpiData", ValidationType.ONLY_EXISTS, "UpiData", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
